@@ -1,6 +1,5 @@
 # -*- coding: utf-8 -*-
-"""The module used to parse the configurations for the various flows
-"""
+"""The module used to parse the configurations for the various flows"""
 
 from __future__ import annotations
 
